@@ -12,7 +12,8 @@ def add_contact(name, address, step, **kwargs):
     w3 = Web3(provider)
     ens_name = None
     try:
-        ens_name = w3.ens.from_web3(w3, address)
+        ns = ENS.from_web3(w3)
+        ens_name = ns.name(address)
         if ens_name:
             print(f"The ENS name for the address {address} is: {ens_name}")
         else:
