@@ -223,8 +223,6 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
       }
     """
     print(f"receiver: {receiver}, amount: {amount}, run_mode: {run_mode}, chain: {chain}, token: {token}, kwargs: {kwargs}, step: {step}")
-    token_raw = token
-    token = w3.to_checksum_address(token_mapping[chain.lower()][token.lower()])
     info = None
     executor = kwargs.get("executor")
     redis_client = kwargs.get("redis_client")
@@ -237,9 +235,15 @@ def transfer(receiver, amount, step, run_mode = 'auto', chain = "base", token =
     provider = Web3.HTTPProvider(providers[chain.lower()])
     provider.middlewares.clear()
     w3 = Web3(provider)
+
+    token_raw = token
+    token = w3.to_checksum_address(token_mapping[chain.lower()][token.lower()])
+
+    print(f"token: {token}, token_raw: {token_raw}")
+
     if run_mode == 'auto':
       """ check executor approved allowance """
-      token = w3.to_checksum_address(token_mapping[chain.lower()][token.lower()]) 
+      # token = w3.to_checksum_address(token_mapping[chain.lower()][token.lower()]) 
       token_contract = w3.eth.contract(address=token, abi=allowance_abi)
       allowance = token_contract.functions.allowance(Web3.to_checksum_address(executor), spender_address).call()
       allowance_normalized = Web3.from_wei(allowance, 'mwei')
